@@ -1,6 +1,7 @@
 /* This file is part of the KDE project
 
    Copyright (C) 2005 Dario Massarin <nekkar@libero.it>
+   Copyright (C) 2009 Lukas Appelhans <l.appelhans@gmx.de>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,27 +23,30 @@
  *  By definition a job must always belong to a JobQueue (see jobqueue.h).
  **/
 
-#include "kget_export.h"
+#include "../kget_export.h"
 
 class QDomNode;
 
 class Scheduler;
 class JobQueue;
 
-class KGET_EXPORT Job
+class KGET_EXPORT Job : public QObject
 {
+    Q_OBJECT
     public:
         /**
          * The status property describes the current job status
          */
         enum Status {
-            Running, /// The job is being executed
-            Delayed, /// The job is delayed. This means that the scheduler should
-                     /// not start it until it exits from the delayed state
-            Stopped, /// The job is stopped
-            Aborted, /// The job is stopped, but this also indicates that it
-                     /// stopped because an error occurred
-            Finished /// The job exited from its Running state successfully
+            Running            = 0, /// The job is being executed
+            Stopped            = 2, /// The job is stopped
+            Aborted            = 3, /// The job is stopped, but this also indicates that it
+                                    /// stopped because an error occurred
+            Finished           = 4, /// The job exited from its Running state successfully
+            FinishedKeepAlive  = 5, /// The job exited from its Running state successfully
+                                    /// but wants to be restarted by the scheduler
+            Moving             = 6  /// The associated files to that job (e.g. Download) are
+                                    /// moved to a different location
         };
 
         /**
@@ -57,18 +61,13 @@ class KGET_EXPORT Job
                    /// queue status
         };
 
-        Job(JobQueue * parent, Scheduler * scheduler);
+        Job(Scheduler * scheduler, JobQueue * parent);
         virtual ~Job();
 
         //Job commands
         virtual void start()=0;
         virtual void stop()=0;
 
-        virtual void setDelay(int seconds)=0;
-        virtual void delayTimerEvent()=0;
-
-        virtual void postDeleteEvent() {}
-
         JobQueue * jobQueue() {return m_jobQueue;}
 
         //Job properties
@@ -81,9 +80,8 @@ class KGET_EXPORT Job
 
         virtual int elapsedTime() const =0;
         virtual int remainingTime() const =0;
-
-        //Job capabilities
-        virtual bool isResumable() const =0;
+        virtual bool isStalled() const =0;
+        virtual bool isWorking() const =0;
 
     protected:
         Scheduler * scheduler() const {return m_scheduler;}
