@@ -48,6 +48,10 @@ class NewTransferDialog;
 class TransferGroupScheduler;
 class TransferHistoryStore;
 
+#ifdef HAVE_NEPOMUK
+class NepomukController;
+#endif
+
 /**
  * This is our KGet class. This is where the user's transfers and searches are
  * stored and organized.
@@ -245,16 +249,6 @@ class KGET_EXPORT KGet
         */
         static bool schedulerRunning();
 
-        /**
-         * Sets the given view to the TransferTreeModel object
-         */
-        static void addTransferView(QAbstractItemView * view);
-
-        /**
-         * Sets the given comboBox to the TransferTreeModel object
-         */
-        static void addTransferView(KComboBox * view);
-
         /**
          * true suspends the scheduler, any events that would result in a reschedule are ignored
          * false wakes up the scheduler, events result in reschedule again
@@ -363,6 +357,10 @@ class KGET_EXPORT KGet
          */
         static QString generalDestDir(bool preferXDGDownloadDir = false);
 
+#ifdef HAVE_NEPOMUK
+        static NepomukController *nepomukController();
+#endif
+
     private:
         KGet();
 
@@ -426,6 +424,10 @@ class KGET_EXPORT KGet
 
         //pointer to the used TransferHistoryStore
         static TransferHistoryStore *m_store;
+
+#ifdef HAVE_NEPOMUK
+        static NepomukController *m_nepomukController;
+#endif
 };
 
 class KGet::TransferData
