@@ -13,37 +13,34 @@
 
 #include <QWidget>
 
-#include "core/observer.h"
 #include "core/transferhandler.h"
 #include "core/plugin/transferfactory.h"
+#include "ui_transferdetailsfrm.h"
 
 class QLabel;
 class QProgressBar;
 class QVBoxLayout;
 
-class TransferDetails : public QWidget, public TransferObserver
+class TransferDetails : public QWidget
 {
     Q_OBJECT
     public:
         TransferDetails(TransferHandler * transfer);
         ~TransferDetails();
 
-        void transferChangedEvent(TransferHandler * transfer);
-
         // gets the generic details widget if the transfer factory doesn't override it
         static QWidget *detailsWidget(TransferHandler *transfer);
+        
+    public slots:
+        void slotTransferChanged(TransferHandler * transfer, TransferHandler::ChangesFlags flags);
+        
     private:
         TransferHandler * m_transfer;
         QVBoxLayout     * m_layout;
         QWidget         * m_genericWidget;
         QWidget         * m_detailsWidget;
 
-        QLabel          * m_statusPixmapLabel;
-        QLabel          * m_statusTextLabel;
-        QLabel          * m_completedLabel;
-        QLabel          * m_speedLabel;
-        QLabel          * m_remainingTimeLabel;
-        QProgressBar    * m_progressBar;
+        Ui::TransferDetailsFrm frm;
 };
 
 #endif
