@@ -126,7 +126,7 @@ void LatexPlugin::slotMessageAboutToShow( Kopete::Message& msg )
 		
 		if (pos >= 0 )
 		{
-			QString match = rg.cap(0);
+			const QString match = rg.cap(0);
 			pos += rg.matchedLength();
 
 			QString formul=match;
@@ -137,7 +137,7 @@ void LatexPlugin::slotMessageAboutToShow( Kopete::Message& msg )
 			if (formul.isEmpty() || !securityCheck(formul))
 				continue;
 			
-			QString fileName = handleLatex(formul);
+			const QString fileName = handleLatex(formul);
 			
 			// get the image and encode it with base64
 			#if ENCODED_IMAGE_MODE
@@ -165,14 +165,14 @@ void LatexPlugin::slotMessageAboutToShow( Kopete::Message& msg )
 	messageText= msg.escapedBody();
 
 	int imagePxWidth,imagePxHeight;
-	for (QMap<QString,QString>::ConstIterator it = replaceMap.begin(); it != replaceMap.end(); ++it)
+	for (QMap<QString,QString>::ConstIterator it = replaceMap.constBegin(); it != replaceMap.constEnd(); ++it)
 	{
 		QImage theImage(*it);
 		if(theImage.isNull())
 			continue;
 		imagePxWidth = theImage.width();
 		imagePxHeight = theImage.height();
-		QString escapedLATEX=Qt::escape(it.key()).replace("\"","&quot;");  //we need  the escape quotes because that string will be in a title="" argument, but not the \n
+		QString escapedLATEX=Qt::escape(it.key()).replace('\"',"&quot;");  //we need  the escape quotes because that string will be in a title="" argument, but not the \n
 		messageText.replace(Kopete::Message::escape(it.key()), " <img width=\"" + QString::number(imagePxWidth) + "\" height=\"" + QString::number(imagePxHeight) + "\" align=\"middle\" src=\"" + (*it) + "\"  alt=\"" + escapedLATEX +"\" title=\"" + escapedLATEX +"\"  /> ");
 	}
 
@@ -211,7 +211,7 @@ void LatexPlugin::slotMessageAboutToSend( Kopete::Message& msg)
 
 		if(!url.isNull())
 		{
-			QString escapedLATEX= Qt::escape(messageText).replace("\"","&quot;");
+			QString escapedLATEX= Qt::escape(messageText).replace('\"',"&quot;");
 			QString messageText="<img src=\"" + url + "\" alt=\"" + escapedLATEX + "\" title=\"" + escapedLATEX +"\"  />";
 			msg.setBody( messageText, Kopete::Message::RichText );
 		}
