@@ -2,7 +2,7 @@
  oscarprotocol.h  -  Oscar Protocol Plugin
 
  Copyright (c) 2002 by Tom Linsky <twl6@po.cwru.edu>
-
+ Copyright (c) 2005 by Matt Rogers <mattr@kde.org>
  Kopete    (c) 2002 by the Kopete developers  <kopete-devel@kde.org>
 
  *************************************************************************
@@ -18,31 +18,26 @@
 #ifndef AIMPROTOCOL_H
 #define AIMPROTOCOL_H
 
-#include "kopeteprotocol.h"
-#include "kopetecontactproperty.h"
+#include "oscarprotocol.h"
 #include "kopetemimetypehandler.h"
 #include "kopeteonlinestatus.h"
 
-#include <qmap.h>
 
-namespace Kopete
-{
-class OnlineStatus;
-}
+class AIMStatusManager;
 
 class AIMProtocolHandler : public Kopete::MimeTypeHandler
 {
 public:
 	AIMProtocolHandler();
-	void handleURL( const KURL & url ) const;
+	void handleURL( const KUrl & url ) const;
 };
 
-class AIMProtocol : public Kopete::Protocol
+class AIMProtocol : public OscarProtocol
 {
 	Q_OBJECT
 
 public:
-	AIMProtocol( QObject *parent, const char *name, const QStringList &args );
+	AIMProtocol( QObject *parent, const QVariantList &args );
 	virtual ~AIMProtocol();
 	/**
 	 * Return the active instance of the protocol
@@ -52,30 +47,18 @@ public:
 
 	bool canSendOffline() const { return false; }
 
-	virtual Kopete::Contact *deserializeContact( Kopete::MetaContact *metaContact,
-	                                             const QMap<QString, QString> &serializedData,
-	                                             const QMap<QString, QString> &addressBookData );
-	
 	AddContactPage*createAddContactWidget( QWidget *parent, Kopete::Account *account );
 	KopeteEditAccountWidget* createEditAccountWidget( Kopete::Account *account, QWidget *parent );
 	Kopete::Account* createNewAccount( const QString &accountId );
 
-	/**
-	 * The set of online statuses that AIM contacts can have
-	 */
-	const Kopete::OnlineStatus statusOnline;
-	const Kopete::OnlineStatus statusOffline;
-	const Kopete::OnlineStatus statusAway;
-	const Kopete::OnlineStatus statusConnecting;
+	OscarStatusManager *statusManager() const;
 
-	const Kopete::ContactPropertyTmpl awayMessage;
-	const Kopete::ContactPropertyTmpl clientFeatures;
-	const Kopete::ContactPropertyTmpl clientProfile;
-	const Kopete::ContactPropertyTmpl iconHash;
+	const Kopete::PropertyTmpl clientProfile;
 
 private:
 	/** The active instance of oscarprotocol */
 	static AIMProtocol *protocolStatic_;
+	AIMStatusManager* statusManager_;
 	AIMProtocolHandler protohandler;
 };
 
