@@ -17,20 +17,25 @@
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 // 02110-1301, USA.
 
-#include "oscarencodingselectionbase.h"
+#include "ui_oscarencodingselectionbase.h"
 #include "oscarencodingselectiondialog.h"
 
 #include <kdebug.h>
-#include <qcombobox.h>
 #include <klocale.h>
 
 OscarEncodingSelectionDialog::OscarEncodingSelectionDialog( QWidget* parent, int initialEncoding )
-    : KDialogBase( parent, 0, false, i18n( "Select Encoding" ), Ok | Cancel )
+    : KDialog( parent )
 {
+	setCaption( i18n( "Select Encoding" ) );
+	setButtons( KDialog::Ok | KDialog::Cancel );
     int initialEncodingIndex;
 
-    clearWFlags( QWidget::WDestructiveClose );
-    m_encodingUI = new OscarEncodingBaseUI( this );
+    setAttribute( Qt::WA_DeleteOnClose, false );
+
+	QWidget* w = new QWidget( this );
+	m_encodingUI = new Ui::OscarEncodingBaseUI;
+	m_encodingUI->setupUi( w );
+
     //fill the encoding combo boxes
   	m_encodings.insert(0, i18n("Default"));
   	m_encodings.insert(2026, i18n("Big5"));
@@ -80,10 +85,10 @@ OscarEncodingSelectionDialog::OscarEncodingSelectionDialog( QWidget* parent, int
 	m_encodings.insert(106, i18n("UTF-8 Unicode"));
 	m_encodings.insert(1015, i18n("UTF-16 Unicode"));
 
-    m_encodingUI->encodingCombo->insertStringList( m_encodings.values() );
-    if( (initialEncodingIndex = m_encodings.keys().findIndex(initialEncoding)) == -1 )
+	m_encodingUI->encodingCombo->insertItems( 0, m_encodings.values() );
+	if( (initialEncodingIndex = m_encodings.keys().indexOf(initialEncoding)) == -1 )
     {
-        kdWarning() << k_funcinfo << "Requested encoding mib " << initialEncoding
+        kWarning() << "Requested encoding mib " << initialEncoding
                 << " not in encoding list - defaulting to first encoding item"
                 << " in list to be shown in combobox initially" << endl;
         /* initialEncodingIndex = position in combobox, value 0 currently
@@ -92,15 +97,21 @@ OscarEncodingSelectionDialog::OscarEncodingSelectionDialog( QWidget* parent, int
          */
         initialEncodingIndex = 0;
     }
-    m_encodingUI->encodingCombo->setCurrentItem( initialEncodingIndex );
-    setMainWidget( m_encodingUI );
+    m_encodingUI->encodingCombo->setCurrentIndex( initialEncodingIndex );
+    setMainWidget( w );
+    connect(this,SIGNAL(okClicked()),this,SLOT(slotOk()));
+    connect(this,SIGNAL(cancelClicked()),this,SLOT(slotCancel()));
 }
 
+OscarEncodingSelectionDialog::~OscarEncodingSelectionDialog()
+{
+    delete m_encodingUI;
+}
 
 int OscarEncodingSelectionDialog::selectedEncoding() const
 {
     QString encoding = m_encodingUI->encodingCombo->currentText();
-    int mib = m_encodings.keys()[ m_encodings.values().findIndex(encoding) ];
+	int mib = m_encodings.keys()[ m_encodings.values().indexOf(encoding) ];
     
     if( mib == -1 )
         return 0;
