@@ -11,6 +11,8 @@
 //
 //
 
+#include "qqchatsession.h"
+
 #include <qlabel.h>
 #include <qvalidator.h>
 //Added by qt3to4:
@@ -38,7 +40,6 @@
 #include "qqaccount.h"
 #include "qqcontact.h"
 #include "qqprotocol.h"
-#include "qqchatsession.h"
 #include <kactioncollection.h>
 
 QQChatSession::QQChatSession( const Kopete::Contact* user, Kopete::ContactPtrList others, Kopete::Protocol* protocol, const QString& guid) : Kopete::ChatSession(user, others, protocol), m_guid( guid ), m_flags( 0 ), m_searchDlg( 0 ), m_memberCount( others.count() )
@@ -288,7 +289,7 @@ void QQChatSession::slotActionInviteAboutToShow()
 	QHash<QString, Kopete::Contact*>::const_iterator it;
 	for ( it = account()->contacts().constBegin(); it != account()->contacts().constEnd(); it++ )
 	{
-		if( !members().contains( it.value() ) && it.value()->isOnline() && it.value() != myself() )
+		if( !members().contains( it.value() ) && it.value()->isOnline() )
 		{
 			KAction *a = new Kopete::UI::ContactAction( it.value(), actionCollection() );
 			m_actionInvite->addAction( a );
@@ -331,7 +332,7 @@ void QQChatSession::slotInviteContact( Kopete::Contact * contact )
 
 void QQChatSession::inviteContact( const QString &contactId )
 {
-	Kopete::Contact * contact = account()->contacts()[ contactId ];
+	Kopete::Contact * contact = account()->contacts().value( contactId );
 	if ( contact )
 		slotInviteContact( contact );
 }
