@@ -1,7 +1,7 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: pppdargs.h 276814 2004-01-04 21:38:58Z mlaurent $
+ * $Id: pppdargs.h 704675 2007-08-25 19:03:00Z amth $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -22,25 +22,27 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef _PPPDARGS_H_
 #define _PPPDARGS_H_
 
-#include <qdialog.h>
+#include <kdialog.h>
+//Added by qt3to4:
+#include <QLabel>
 
-class QListBox;
+class Q3ListBox;
 class QLabel;
 class QPushButton;
 class QLineEdit;
 class KPushButton;
 
 
-class PPPdArguments : public QDialog {
+class PPPdArguments : public KDialog {
 Q_OBJECT
 public:
-  PPPdArguments(QWidget *parent=0, const char *name=0);
+  explicit PPPdArguments(QWidget *parent=0, const char *name=0);
   ~PPPdArguments() {}
 
 private slots:
@@ -62,7 +64,7 @@ private:
   QPushButton *remove;
   KPushButton *defaults;
 
-  QListBox *arguments;
+  Q3ListBox *arguments;
 
   QPushButton *closebtn;
 };
