@@ -12,7 +12,7 @@
 //
 //---------------------------------------------------------------------------
 //
-//  $Id: providerdb.h 212185 2003-03-07 22:11:39Z waba $
+//  $Id: providerdb.h 635496 2007-02-20 07:05:07Z coolo $
 //
 //---------------------------------------------------------------------------
 //
@@ -28,19 +28,19 @@
 //
 //  You should have received a copy of the GNU Library General Public
 //  License along with this program; if not, write to the Free
-//  Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+//  Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 //
 //---------------------------------------------------------------------------
 
 #ifndef PROVIDER_DB
 #define PROVIDER_DB
 
-#include <kwizard.h>
+#include <k3wizard.h>
 #include <qwidget.h>
 
 class QLineEdit;
-class QListBox;
-class KSimpleConfig;
+class Q3ListBox;
+class KConfig;
 
 class PDB_Intro : public QWidget {
   Q_OBJECT
@@ -54,7 +54,7 @@ class PDB_Country : public QWidget {
 public:
   PDB_Country(QWidget *parent);
   ~PDB_Country();
-  QListBox *lb;
+  Q3ListBox *lb;
   QStringList *list;
 
 public slots:
@@ -70,7 +70,7 @@ public:
   void setDir(const QString &d);
   QString getDir();
 
-  QListBox *lb;
+  Q3ListBox *lb;
 
 public slots:
   void selectionChanged(int);
@@ -116,12 +116,12 @@ public:
 };
 
 
-class ProviderDB : public KWizard {
+class ProviderDB : public K3Wizard {
   Q_OBJECT
 public:
   ProviderDB(QWidget *parent);
   ~ProviderDB();
-  static QWizard *wiz;
+  static Q3Wizard *wiz;
 
 public slots:
   void pageSelected();
@@ -129,7 +129,7 @@ public slots:
 
 private:
   void loadProviderInfo();
-  KSimpleConfig *cfg;
+  KConfig *cfg;
 
   PDB_Intro *page1;
   PDB_Country *page2;
