@@ -1,7 +1,7 @@
 /*
  *              kPPP: A pppd Front End for the KDE project
  *
- * $Id: requester.cpp 212185 2003-03-07 22:11:39Z waba $
+ * $Id: requester.cpp 695881 2007-08-03 07:19:24Z mlaurent $
  *
  *              Copyright (C) 1997,98 Bernd Johannes Wuebben,
  *		                      Mario Weilguni,
@@ -23,7 +23,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifdef __osf__
@@ -119,10 +119,10 @@ int Requester::recvFD() {
   signal(SIGALRM, SIG_DFL);
 
   if(len <= 0) {
-    kdError(5002) << "recvmsg failed " << strerror(errno) << endl;
+    kError(5002) << "recvmsg failed " << strerror(errno) << endl;
     return -1;
   } else if (msg.msg_controllen < cmsglen) {
-    kdError(5002) << "recvmsg: truncated message " << strerror(errno) << endl;
+    kError(5002) << "recvmsg: truncated message " << strerror(errno) << endl;
     exit(1);
   } else {
 #ifdef CMSG_DATA
@@ -130,7 +130,7 @@ int Requester::recvFD() {
 #else
     fd = *((int *) control.cmsg.cmsg_data);
 #endif
-    kdDebug(5002) << "response.status: " << response.status << endl;
+    kDebug(5002) << "response.status: " << response.status;
     assert(response.status <= 0);
     if(response.status < 0)
       return response.status;
@@ -155,16 +155,16 @@ bool Requester::recvResponse() {
 
   iov.iov_base = IOV_BASE_CAST &response;
   iov.iov_len = sizeof(struct ResponseHeader);
-  kdDebug(5002) << "recvResponse(): waiting for message" << endl;
+  kDebug(5002) << "recvResponse(): waiting for message";
   len = recvmsg(socket, &msg, flags);
-  kdDebug(5002) << "recvResponse(): received message" << endl;
+  kDebug(5002) << "recvResponse(): received message";
   if (len <= 0) {
     if (errno == EINTR)
-      kdDebug(5002) << "Interrupted system call. Continuing." << endl;
+      kDebug(5002) << "Interrupted system call. Continuing.";
     else
       perror("recvmsg failed");
   } else {
-    kdDebug(5002) << "response.status: " << response.status << endl;
+    kDebug(5002) << "response.status: " << response.status;
   }
 
   lastStatus = response.status;
@@ -230,8 +230,11 @@ int Requester::openSysLog() {
 
 
 bool Requester::setSecret(int method, const QString &name, const QString &password) {
-  assert(name!=0);
-  assert(password!=0);
+#ifdef __GNUC__
+#warning check if QString != 0 means using isNull or isEmpty
+#endif
+  assert(!name.isNull());
+  assert(!password.isNull());
 
   if(method == AUTH_PAPCHAP)
     return setSecret(AUTH_PAP, name, password) &&
@@ -341,9 +344,9 @@ bool Requester::sendRequest(struct RequestHeader *request, int len) {
   msg.msg_iovlen = 1;
   msg.msg_control = 0L;
   msg.msg_controllen = 0;
-  kdDebug(5002) << "sendRequest: trying to send msg type " << request->type << endl;
+  kDebug(5002) << "sendRequest: trying to send msg type " << request->type;
   sendmsg(socket, &msg, 0);
-  kdDebug(5002) << "sendRequest: sent message" << endl;
+  kDebug(5002) << "sendRequest: sent message";
 
   return true;
 }
@@ -361,5 +364,5 @@ int Requester::indexDevice(const QString &dev) {
 
 
 void recv_timeout(int) {
-  kdDebug(5002) << "timeout()" << endl;
+  kDebug(5002) << "timeout()";
 }
