@@ -603,7 +603,7 @@ void MainWindow::disconnectHost()
 
 void MainWindow::closeTab(QWidget *widget)
 {
-    bool isNewConnectionPage = m_tabWidget->currentWidget() == m_newConnectionWidget;
+    bool isNewConnectionPage = widget == m_newConnectionWidget;
     const int index = m_tabWidget->indexOf(widget);
 
     kDebug(5010) << index;
@@ -1054,7 +1054,7 @@ void MainWindow::tabChanged(int index)
 
     if (m_tabWidget->currentWidget() == m_newConnectionWidget) {
         m_currentRemoteView = -1;
-        m_addressInput->setFocus();
+        if(m_addressInput) m_addressInput->setFocus();
     }
 
     const QString tabTitle = m_tabWidget->tabText(index).remove('&');
